@@ -3,8 +3,10 @@ Jupyter notebook integration for vizzu.
 """
 
 import json
+import abc
+import typing
 
-from IPython.display import HTML, display_html
+from IPython.display import display_html
 
 
 _HEAD = """
@@ -17,7 +19,23 @@ chart.initializing.then( chart => {{
 """
 
 
-class Data(dict):
+class Animation:
+    def dump(self):
+        return json.dumps(self.build())
+
+    @abc.abstractmethod
+    def build(self) -> typing.Mapping:
+        """
+        Return a dict with native python values that can be converted into json.
+        """
+
+
+class PlainAnimation(dict, Animation):
+    def build(self):
+        return self
+
+
+class Data(dict, Animation):
     """
     Vizzu data with the required keys: records, series, dimensions or measures.
     """
@@ -45,10 +63,39 @@ class Data(dict):
     def _add_value(self, dest, value):
         self.setdefault(dest, []).append(value)
 
+    def build(self):
+        return {"data": self}
+
+
+class Config(dict, Animation):
+    def build(self):
+        return {"config": self}
+
+
+class AnimationMerger(dict, Animation):
+    def build(self):
+        return self
+
+    def merge(self, animation: Animation):
+        data = self._validate(animation)
+        self.update(data)
+
+    def _validate(self, animation):
+        data = animation.build()
+        common_keys = set(data).intersection(self)
+        assert not common_keys, f"Animation is already merged: {common_keys}"
+        return data
+
+
+class Style(dict, Animation):
+    def build(self):
+        return {"style": self}
+
 
 class Method:
+    @abc.abstractmethod
     def dump(self):
-        raise NotImplementedError
+        pass
 
 
 class Animate(Method):
@@ -56,11 +103,10 @@ class Animate(Method):
         self._data = data
 
     def dump(self):
-        data = json.dumps(self._data)
+        data = self._data.dump()
         return f"chart.animate({data});"
 
 
-
 class Feature(Method):
     def __init__(self, name, value):
         self._name = name
@@ -77,32 +123,39 @@ class Chart:
     Wrapper over vizzu Chart
     """
 
-    def __init__(self, **data):
+    def __init__(self):
         self._calls = []
 
-    def set_data(self, data: Data):
-        """
-        Set new data for animation.
-        """
-
-        self._calls.append(Animate({"data": data}))
-
-    def set_config(self, config):
-        """
-        Set new configuration.
-        """
-
-        self._calls.append(Animate({"config": config}))
-
-    def set_feature(self, name, value):
+    def feature(self, name, value):
         self._calls.append(Feature(name, value))
 
-    def animate(self, **config):
+    def animate(self, *animations: Animation, **config):
         """
-        Change the animation config.
+        Register new animation.
         """
+        if animations and config:
+            raise ValueError(
+                "`animations` parameter cannot be updated with keyword arguments."
+            )
 
-        self._calls.append(Animate(config))
+        if not animations and not config:
+            raise ValueError("No animation was set.")
+
+        if config:
+            animation = PlainAnimation(config)
+
+        else:
+            animation = self._merge_animations(animations)
+
+        self._calls.append(Animate(animation))
+
+    def _merge_animations(self, animations):
+        merger = AnimationMerger()
+
+        for animation in animations:
+            merger.merge(animation)
+
+        return merger
 
     def show(self):
         """
@@ -113,5 +166,4 @@ class Chart:
         script.extend(call.dump() for call in self._calls)
         script.append("} );")
         script.append("</script>")
-
         display_html("\n".join(script), raw=True)
